@@ -20,6 +20,7 @@ from genericpath import isdir
 from pathlib import Path
 import win32con, win32api
 import copy
+from os.path import exists
 
 
 class autoexport:
@@ -617,6 +618,12 @@ class autoexport:
         location_app = "C:\\Program Files (x86)\\Avirtech\\Avirkey"
 
         path_move = os.path.join(location_copied,dir_name)
+
+        if exists(path_move):
+                shutil.rmtree(path_move)
+        else:
+            pass
+
         if os.path.isdir(path_move):
             pass
         elif not os.path.isdir(path_move):
